pub(crate) enum Notification {
Exit,
QueuePrompt(String),
ForceSubmitQueued,
Continue,
}Expand description
Notifications to be sent to the agent
Variants
Exit
Notify of an exit event
QueuePrompt(String)
Queue the given prompt until the next cycle where we can naturally submit it
ForceSubmitQueued
Force submitting all queued prompts right now
Continue
Submit the current state without a new user message (e.g. continue a resumed session)