Incoming

Struct Incoming 

struct Incoming {
    notifications: UnboundedReceiver<Notification>,
    queued_messages: VecDeque<String>,
}
Incoming notification processing

Fields

notifications: UnboundedReceiver<Notification>

Notifications from the application

queued_messages: VecDeque<String>

User messages queued

Implementations

Source

impl Incoming

async fn wait_for_abort(&mut self) -> bool

Process all available incoming notifications, until any abort notification is received

Abort notifications are Exit and ForceSubmitQueued, or the channel being closed.

Return true if we need to exit, false if we just need to abort and submit everything that’s queued.